@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.50';
+$Geo::Address::Formatter::VERSION = '1.51';
 use strict;
 use warnings;
 
@@ -276,8 +276,18 @@ sub _determine_country_code {
             my $old_cc = $cc;
             $cc = $self->{templates}{$cc}{use_country};
             if (defined( $self->{templates}{$old_cc}{change_country} )){
-		$rh_components->{country} = 
-		    $self->{templates}{$old_cc}{change_country};
+
+                my $new_country = $self->{templates}{$old_cc}{change_country};
+                if ($new_country =~ m/\$(\w*)/){
+                    my $component = $1;
+                    if ( defined($rh_components->{$component}) ){
+			$new_country =~ s/\$$component/$rh_components->{$component}/;
+                    } else {
+			$new_country =~ s/\$$component//;
+                    }
+                }
+		$rh_components->{country} = $new_country; 
+		    
             } 
             if (defined( $self->{templates}{$old_cc}{add_component} )){
                 my $tmp = $self->{templates}{$old_cc}{add_component};
@@ -463,7 +473,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.50
+version 1.51
 
 =head1 SYNOPSIS
 
